==> liveqa-1.0.0.tgz: package/distribution/config.js <==
'use strict';

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var Config = function () {
  function Config() {
    (0, _classCallCheck3.default)(this, Config);
  }

  (0, _createClass3.default)(Config, null, [{
    key: 'VERSION',
    get: function get() {
      return '0.0.1';
    }
  }, {
    key: 'LIBRARY_NAME',
    get: function get() {
      return 'liveqa';
    }
  }, {
    key: 'LANGUAGE',
    get: function get() {
      return 'javascript';
    }
  }, {
    key: 'HOST',
    set: function set(value) {
      this._host = value;
    },
    get: function get() {
      return this._host || 'https://api.liveqa.io';
    }
  }, {
    key: 'API_VERSION',
    get: function get() {
      return 'v1';
    }
  }, {
    key: 'SNIPPET_VERSION',
    set: function set(value) {
      this._snippetVersion = value;
    },
    get: function get() {
      return this._snippetVersion;
    }
  }, {
    key: 'API_KEY',
    set: function set(value) {
      this._apiKey = value;
    },
    get: function get() {
      return this._apiKey;
    }
  }, {
    key: 'IDENTIFIER_COOKIE_NAME',
    get: function get() {
      return 'fl_identifier_id';
    }
  }]);
  return Config;
}();

module.exports = Config;

==> liveqa-1.1.0.tgz: package/distribution/config.js <==
'use strict';

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var Config = function () {
  function Config() {
    (0, _classCallCheck3.default)(this, Config);
  }

  (0, _createClass3.default)(Config, null, [{
    key: 'version',
    get: function get() {
      return '1.1.0';
    }
  }, {
    key: 'libraryName',
    get: function get() {
      return 'liveqa';
    }
  }, {
    key: 'language',
    get: function get() {
      return 'javascript';
    }
  }, {
    key: 'host',
    set: function set(value) {
      this._host = value;
    },
    get: function get() {
      return this._host || 'https://api.liveqa.io';
    }
  }, {
    key: 'apiVersion',
    get: function get() {
      return 'v1';
    }
  }, {
    key: 'snippetVersion',
    set: function set(value) {
      this._snippetVersion = value;
    },
    get: function get() {
      return this._snippetVersion;
    }
  }, {
    key: 'apiKey',
    set: function set(value) {
      this._apiKey = value;
    },
    get: function get() {
      return this._apiKey;
    }
  }, {
    key: 'identifierCookieName',
    get: function get() {
      return 'liveqa_identifier_id';
    }
  }, {
    key: 'enabled',
    set: function set(value) {
      this._enabled = value;
    },
    get: function get() {
      return this._enabled === undefined ? true : this._enabled;
    }
  }, {
    key: 'obfuscatedFields',
    set: function set(value) {
      this._obfuscatedFields = value;
    },
    get: function get() {
      return this._obfuscatedFields === undefined ? [] : this._obfuscatedFields;
    }
  }]);
  return Config;
}();

module.exports = Config;
